@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_cloudwatch._jsii
 import aws_cdk.aws_iam._jsii
@@ -15,7 +15,7 @@ import aws_cdk.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@aws-cdk/aws-sqs", "1.54.0", __name__[0:-6], "aws-sqs@1.54.0.jsii.tgz"
+    "@aws-cdk/aws-sqs", "1.65.0", __name__[0:-6], "aws-sqs@1.65.0.jsii.tgz"
 )
 
 __all__ = [
